@@ -1,12 +1,16 @@
-#include <stdio.h>
-#include <math.h>
-#include <stdlib.h>
-#include <time.h>
+//#include <stdio.h>
+#include <cstdio>
+//#include <math.h>
+#include <cmath>
+//#include <stdlib.h>
+#include <cstdlib>
+//#include <time.h>
+#include <ctime>
 
-extern "C" {
+//extern "C" {
 #include <R.h>
 #include <Rmath.h>
-};
+//};
 
 #include "global.h"
 #include "List.h"
